# parts: BTS7960

- 43 A, H-Bridge Motor Driver
- specs: [BTS7960](https://www.handsontec.com/dataspecs/module/BTS7960%20Motor%20Driver.pdf)

|   |
| --- |
| ![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/bts7960.jpg?raw=true) |
